Types
=====


String based types
------------------

.. autoclass:: confiture.schema.types.String
.. autoclass:: confiture.schema.types.Regex
.. autoclass:: confiture.schema.types.NamedRegex
.. autoclass:: confiture.schema.types.RegexPattern
.. autoclass:: confiture.schema.types.IPAddress
.. autoclass:: confiture.schema.types.IPNetwork
.. autoclass:: confiture.schema.types.Url
.. autoclass:: confiture.schema.types.IPSocketAddress
.. autoclass:: confiture.schema.types.Eval
.. autoclass:: confiture.schema.types.Path


Number based types
------------------

.. autoclass:: confiture.schema.types.Integer
.. autoclass:: confiture.schema.types.Float


Boolean based types
-------------------

.. autoclass:: confiture.schema.types.Boolean
